@@ -35,10 +35,11 @@ require_once('tasks/CITask.php');
  *
  * @author Peter Bubestinger-Steindl (pb@av-rd.com)
  * @copyright
- *  Copyright 2016, Peter Bubestinger-Steindl
+ *  Copyright 2018 AV-RD e.U.
  *  (License: <a href="http://www.gnu.org/licenses/gpl.html">GNU General Public License (v3)</a>)
  *
  * @see
+ *  - <a href="http://www.av-rd.com/products/cinbox/">CInbox product website</a>
  *  - <a href="http://www.av-rd.com/">AV-RD website</a>
  *  - <a href="https://fsfe.org/about/basics/freesoftware.en.html">FSFE: What is Free Software?</a>
  *  - <a href="http://www.gnu.org/licenses/gpl.html">The GNU General Public License</a>
@@ -235,6 +236,8 @@ class CIItem extends CIFolder
         $config = $this->config;
         $config->initPlaceholders();
         $config->addPlaceholder(__ITEM_ID__, $itemId);                  // Add current item id as placeholder value.
+        $config->addPlaceholder(__ITEM_ID_UC__, strtoupper($itemId));   // Uppercase
+        $config->addPlaceholder(__ITEM_ID_LC__, strtolower($itemId));   // Lowercase
 
         $configArray = $config->getConfigForSection(self::CONF_SECTION_ITEM);
 
@@ -375,6 +378,7 @@ class CIItem extends CIFolder
                     'RenameTarget',             // Move temp target files to final position.
                     'HashOutput',               // Write hashcodes to target in selected format
                     'PostProcs',                // Same as PreProcs, but on the target
+                    'LogfileCopy',              // Copy-and-rename logfile to a separate location
                     ),
                 );
 
