@@ -30,10 +30,11 @@ require_once('include/FileCV.php');
  *
  * @author Peter Bubestinger-Steindl (pb@av-rd.com)
  * @copyright
- *  Copyright 2016, Peter Bubestinger-Steindl
+ *  Copyright 2018 AV-RD e.U.
  *  (License: <a href="http://www.gnu.org/licenses/gpl.html">GNU General Public License (v3)</a>)
  *
  * @see
+ *  - <a href="http://www.av-rd.com/products/cinbox/">CInbox product website</a>
  *  - <a href="http://www.av-rd.com/">AV-RD website</a>
  *  - <a href="https://fsfe.org/about/basics/freesoftware.en.html">FSFE: What is Free Software?</a>
  *  - <a href="http://www.gnu.org/licenses/gpl.html">The GNU General Public License</a>
@@ -63,6 +64,12 @@ class Logger
     const OUT_OPT_TIMESTAMPS = 2;
     const OUT_OPT_INSTANCEID = 3;
 
+    // NOTE: If you add or change these values, don't forget to update
+    //       the --help text in 'cinbox.php'.
+    // Output formats:
+    const OUT_STYLE_CLASSIC = 0;
+    const OUT_STYLE_FILECV = 1;
+
     // Output formatting:
     const HEADLINE_CHAR1 = '=';
     const HEADLINE_CHAR2 = '-';
@@ -87,6 +94,11 @@ class Logger
             self::LEVEL_DEBUG
             );
 
+    private static $logStyles = array(
+            'classic' => self::OUT_STYLE_CLASSIC,
+            'cv' => self::OUT_STYLE_FILECV
+            );
+
     private $msgBuffer;
     private $msgOutput;
     private $logfile = null;
@@ -121,11 +133,65 @@ class Logger
 
 
     /**
-     * Activate or deactivatr usage of FileCV format.
+     * Checks if the given $logstyle is a valid option.
+     * You can also use validateOutputFormat(), if you use Exception handling.
+     *
+     * @see $logStyles
+     * @see validateOutputFormat()
+     * @return True if valid, False if not.
      */
-    public function setUsingFileCV($use_file_cv)
+    public static function isValidOutputFormat($logstyle)
     {
-        $this->useFileCV = !!$use_file_cv;
+        return array_key_exists($logstyle, self::$logStyles) ? true : false;
+    }
+
+
+    /**
+     * Similar to isValidOutputFormat(), but already throws an exception
+     * including an error message.
+     *
+     * @throws DomainException If $logstyle is not a valid output format option.
+     * @see $logStyles
+     * @see isValidOutputFormat()
+     */
+    public static function validateOutputFormat($logstyle)
+    {
+        if (!self::isValidOutputFormat($logstyle))
+        {
+            throw new DomainException(sprintf(
+                _("Invalid logstyle: '%s'. Valid options are: %s"),
+                $logstyle,
+                implode(', ', array_keys(self::$logStyles))
+                ));
+        }
+
+        return true;
+    }
+
+
+    /**
+     * Change output format.
+     * Current options for $logstyle:
+     *   - 0: classic
+     *   - 1: fileCV
+     *
+     * @see $logStyles
+     */
+    public function setOutputFormat($logstyle)
+    {
+        $logstyleNum = self::$logStyles[$logstyle];
+
+        switch ($logstyleNum)
+        {
+            case self::OUT_STYLE_FILECV:
+                $this->useFileCV = true;
+                break;
+            default:
+                // Defaults to "classic".
+                $this->useFileCV = false;
+                break;
+        }
+
         if ($this->useFileCV && !$this->cv)
         {
           // Instantiate a file CV (log).
@@ -248,11 +314,25 @@ class Logger
     }
 
 
+    /**
+     * Gives the name of the logfile (path + filename) as string.
+     * If filename is empty (or not set yet), it returns False.
+     *
+     * @return string if set, False if not (or empty).
+     * @retval $filename    Name of the logfile (path+filename).
+     */
+    public function getLogfile()
+    {
+        if (!empty($this->logfile)) return $this->logfile;
+        return false;
+    }
+
+
     /**
      * Used to set the boolean flag whether to show the timestamp in log messages.
      *
      * @param boolean   flag    Turn timestamp on/off (true  = show timestamp, false = hide timestamp).
-     * @see $this->showTimestamp
+     * @see $showTimestamp
      */
     public function showTimestamp($flag)
     {
@@ -268,7 +348,7 @@ class Logger
      * is useful to debug which Logger object was used where.
      *
      * @param boolean   flag    Turn instance ID on/off (true = show instance ID, false = hide instance ID).
-     * @see $this->showInstanceId
+     * @see $showInstanceId
      */
     public function showInstanceId($flag)
     {
@@ -283,8 +363,8 @@ class Logger
      *
      * This is the main routine for logging messages.
      *
-     * @see $this->msgBuffer
-     * @see $this->outputMsgBuffer()
+     * @see $msgBuffer
+     * @see outputMsgBuffer()
      */
     public function addMessage($logLevel, $message, $source=null, $lineNumber=null)
     {
@@ -299,9 +379,9 @@ class Logger
      * Outputs the current message buffer to different output formats (screen, file, etc).
      * The message buffer is cleared afterwards.
      *
-     * @see $this->msgOutput
-     * @see $this->showTimestamp()
-     * @see $this->showInstanceId()
+     * @see $msgOutput
+     * @see showTimestamp()
+     * @see showInstanceId()
      */
     public function outputMsgBuffer()
     {
@@ -327,8 +407,11 @@ class Logger
                     {
                       $itemdir = dirname($itemdir);
                     }
-                    $archive_item = new ArchiveItem('directory', $itemdir);
-                    // Putting anything into the item dir actually makesthe item not be processed,
+
+                    // FIXME: Possibly "unclean" way deriving the item-id, assuming it to be the basename():
+                    $archive_item = new ArchiveItem('directory', basename($itemdir));
+
+                    // Putting anything into the item dir actually makes the item not be processed,
                     // so override logfile path and use what Logger traditionally uses.
                     $this->cv->setOverrideLogfile($this->logfile);
                     $log_type = FileCV::LOG_ENTRY_TYPE_ADD; // CInbox always adds.
@@ -363,7 +446,7 @@ class Logger
                         // and its log level is at least the target level.
                         if (strlen($message) && ($eLogLevel >= $logLevel))
                         {
-                            $this->cv->log($archive_item, 'auto-cinbox', $log_type, $log_level, preg_replace("/\n/", '\n', $message));
+                            $this->cv->log($archive_item, 'auto-cinbox', $log_type, $log_level, $message);
                         }
                     }
                 }
@@ -514,6 +597,17 @@ class Logger
     }
 
 
+    /**
+     * Writes the message to the logfile, without any headers, prefix or anything.
+     * Just plain, as-is.
+     * Currently, it's identical to calling "writeToLogFile()".
+     */
+    public function logPlain($msg)
+    {
+        return $this->writeToLogfile($msg);
+    }
+
+
     /**
      * Logs the given exception $e as error message.
      */
